@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: dwmauth.cc 10667 2020-05-03 18:51:46Z dwm $
+// @(#) $Id: dwmauth.cc 11321 2020-12-02 20:57:16Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -54,7 +54,7 @@ extern "C" {
 #include "DwmSvnTag.hh"
 #include "DwmAuthPublicKeysFile.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.9/apps/dwmauth/dwmauth.cc 10667 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.12/apps/dwmauth/dwmauth.cc 11321 $");
 
 using namespace std;
 using namespace Dwm;
@@ -211,7 +211,7 @@ bool CheckKeys(int argc, char *argv[])
         Auth::PublicKeysFile  ak;
         if (ak.Load(pubFile)) {
           if (ak.Keys().size() == 1) {
-            kp.second = ak.Keys().begin()->second;
+            kp.Public() = ak.Keys().begin()->second;
             if (kp.Public().IsValid()) {
               CryptoPP::ByteQueue  pubbt;
               kp.Private().Save(pubbt);
