@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.9/src/DwmAuthEd25519Keys.cc 11162 $
-// @(#) $Id: DwmAuthEd25519Keys.cc 11162 2020-09-08 06:46:41Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.12/src/DwmAuthEd25519Keys.cc 11318 $
+// @(#) $Id: DwmAuthEd25519Keys.cc 11318 2020-12-02 20:02:09Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018, 2020
 //  All rights reserved.
@@ -572,7 +572,7 @@ namespace Dwm {
       name.clear();
       ifstream  privis(privKeyPath.c_str(), ios_base::in | ios_base::binary);
       if (privis) {
-        if (first.Read(privis)) {
+        if (_keys.first.Read(privis)) {
           string  pubKeyPath(privKeyPath + ".pub");
           ifstream  pubis(pubKeyPath.c_str(), ios_base::in | ios_base::binary);
           if (pubis) {
@@ -584,8 +584,8 @@ namespace Dwm {
               smatch  sm;
               if (regex_match(s, sm, rgx)) {
                 if ((sm.size() == 4) && (sm[2].str() == "dwm-ed25519")) {
-                  if (second.FromBase64String(sm[3].str())) {
-                    if (second.IsValid()) {
+                  if (_keys.second.FromBase64String(sm[3].str())) {
+                    if (_keys.second.IsValid()) {
                       name = sm[1].str();
                       rc = true;
                     }
