@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmAuthPeerAuthenticator.cc 11215 2020-11-10 05:34:23Z dwm $
+// @(#) $Id: DwmAuthPeerAuthenticator.cc 11369 2020-12-09 07:25:44Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017, 2020
 //  All rights reserved.
@@ -58,6 +58,7 @@ extern "C" {
 #include <cryptopp/secblock.h>
 
 #include "DwmDescriptorIO.hh"
+#include "DwmIpAddress.hh"
 #include "DwmStreamIO.hh"
 #include "DwmIOUtils.hh"
 #include "DwmSvnTag.hh"
@@ -66,7 +67,7 @@ extern "C" {
 #include "DwmAuthSymCrypto.hh"
 #include "DwmAuthUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.9/src/DwmAuthPeerAuthenticator.cc 11215 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.12/src/DwmAuthPeerAuthenticator.cc 11369 $");
 
 using namespace std;
 using CryptoPP::PSS;
@@ -80,6 +81,54 @@ namespace Dwm {
 
   namespace Auth {
 
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    static bool GetPeerName(int fd, IpAddress & addr, uint16_t & port)
+    {
+      bool  rc = false;
+      addr = IpAddress();
+      port = 0;
+      if (0 <= fd) {
+        struct sockaddr_storage  clientAddr;
+        socklen_t socklen = sizeof(clientAddr);
+        if (getpeername(fd, (struct sockaddr *)&clientAddr, &socklen) == 0) {
+          if (AF_INET == clientAddr.ss_family) {
+            struct sockaddr_in  *sinAddr = (struct sockaddr_in *)&clientAddr;
+            addr = Ipv4Address(sinAddr->sin_addr.s_addr);
+            port = ntohs(sinAddr->sin_port);
+            rc = true;
+          }
+          else if (AF_INET6 == clientAddr.ss_family) {
+            struct sockaddr_in6  *sin6Addr = (struct sockaddr_in6 *)&clientAddr;
+            addr = Ipv6Address(sin6Addr->sin6_addr);
+            port = ntohs(sin6Addr->sin6_port);
+            rc = true;
+          }
+        }
+        else {
+          Syslog(LOG_ERR, "getpeername(%d, %p, %p) failed: %m",
+                 fd, &clientAddr, &socklen);
+        }
+      }
+      return rc;
+    }
+
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    static string GetPeerName(int fd)
+    {
+      string  rc;
+      IpAddress  addr;
+      uint16_t   port;
+      if (GetPeerName(fd, addr, port)) {
+        rc = (string)addr + ":";
+        rc += to_string(port);
+      }
+      return rc;
+    }
+
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -146,7 +195,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool PeerAuthenticator::ECExchange(int fd,
+    bool PeerAuthenticator::ECExchange(int fd, const std::string & peerName,
                                        Auth::ECDHAgreement & agreement)
     {
       bool  rc = false;
@@ -164,19 +213,23 @@ namespace Dwm {
                 rc = true;
               }
               else {
-                Syslog(LOG_ERR, "Failed to reach agreement");
+                Syslog(LOG_ERR, "Failed to reach agreement with %s on fd %d",
+                       peerName.c_str(), fd);
               }
             }
             else {
-              Syslog(LOG_ERR, "Read(%d) failed: %m", fd);
+              Syslog(LOG_ERR, "Read from %s on fd %d failed: %m",
+                     peerName.c_str(), fd);
             }
           }
           else {
-            Syslog(LOG_ERR, "Peer took to long to send EC exchange");
+            Syslog(LOG_ERR, "Peer %s on fd %d took to long to send EC exchange",
+                   peerName.c_str(), fd);
           }
         }
         else {
-          Syslog(LOG_ERR, "Write(%d) failed: %m", fd);
+          Syslog(LOG_ERR, "Write to %s on fd %d failed: %m",
+                 peerName.c_str(), fd);
         }
       }
       return rc;
@@ -257,7 +310,7 @@ namespace Dwm {
       if (WriteString(s, mypubEC)) {
         string  theirPubECDH;
         if (Utils::WaitForBytesReady(s, 36, chrono::milliseconds(5000))) {
-          if (Utils::ReadLengthRestrictedString(s, theirPubECDH, 32)) {
+          if (Utils::ReadLengthRestrictedString(s, theirPubECDH, 32) > 0) {
             agreement.TheirPublic(to_SecByteBlock(theirPubECDH));
             if (agreement.Agree()) {
               rc = true;
@@ -309,12 +362,13 @@ namespace Dwm {
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
-    bool PeerAuthenticator
-    ::IDAndSigExchange(int fd,
-                       const ECDHAgreement & agreement,
-                       string & theirId,
-                       string & theirIdCrypted,
-                       string & theirSig)
+    bool
+    PeerAuthenticator::IDAndSigExchange(int fd,
+                                        const std::string & peerName,
+                                        const ECDHAgreement & agreement,
+                                        string & theirId,
+                                        string & theirIdCrypted,
+                                        string & theirSig)
     {
       bool  rc = false;
       if (fd >= 0) {
@@ -332,19 +386,23 @@ namespace Dwm {
                 rc = true;
               }
               else {
-                Syslog(LOG_ERR, "Failed to read signature");
+                Syslog(LOG_ERR, "Failed to read signature from %s on fd %d",
+                       peerName.c_str(), fd);
               }
             }
             else {
-              Syslog(LOG_ERR, "Failed to read encrypted ID");
+              Syslog(LOG_ERR, "Failed to read encrypted ID from %s on fd %d",
+                     peerName.c_str(), fd);
             }
           }
           else {
-            Syslog(LOG_ERR, "Failed to read ID and signature from %d", fd);
+            Syslog(LOG_ERR, "Failed to read ID and signature from %s on fd %d",
+                   peerName.c_str(), fd);
           }
         }
         else {
-          Syslog(LOG_ERR, "Failed to write ID and signature to %d", fd);
+          Syslog(LOG_ERR, "Failed to write ID and signature to %s on fd %d",
+                 peerName.c_str(), fd);
         }
       }
       return rc;
@@ -365,7 +423,7 @@ namespace Dwm {
       if (WriteString(sck, idAndSig)) {
         string  s;
         auto  endTime = chrono::system_clock::now() + chrono::milliseconds(5000);
-        if (Utils::ReadLengthRestrictedString(sck, s, 2048, endTime)) {
+        if (Utils::ReadLengthRestrictedString(sck, s, 2048, endTime) > 0) {
           string  keystr((to_str(agreement.AgreedKey())).substr(0, 16));
           string  ivstr((to_str(agreement.AgreedKey())).substr(16, 16));
           istringstream  is(s);
@@ -391,7 +449,7 @@ namespace Dwm {
       }
       return rc;
     }
-    
+
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -402,10 +460,7 @@ namespace Dwm {
       theirId.clear();
       agreedKey.clear();
       if (fd >= 0) {
-        struct sockaddr_in  sockAddr;
-        socklen_t           sockLen = sizeof(sockAddr);
-        getpeername(fd, (struct sockaddr *)&sockAddr, &sockLen);
-
+        string  peerName = GetPeerName(fd);
         int origTcpNoDelay;
         socklen_t  tcpNoDelayLen = sizeof(origTcpNoDelay);
         getsockopt(fd, IPPROTO_TCP, TCP_NODELAY, (char *)&origTcpNoDelay,
@@ -413,10 +468,12 @@ namespace Dwm {
         int tcpNoDelay = 1;
         setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, (char *)&tcpNoDelay,
                    sizeof(tcpNoDelay));
+        Syslog(LOG_DEBUG, "Authenticating connection from %s on fd %d",
+               peerName.c_str(), fd);
         Auth::ECDHAgreement  agreement;
-        if (ECExchange(fd, agreement)) {
+        if (ECExchange(fd, peerName, agreement)) {
           string  theirIdCrypted, theirSig;
-          if (IDAndSigExchange(fd, agreement, theirId,
+          if (IDAndSigExchange(fd, peerName, agreement, theirId,
                                theirIdCrypted, theirSig)) {
             Auth::PublicKeysFile  pubKeysFile;
             pubKeysFile.Load(_pubKeysPath);
@@ -435,8 +492,9 @@ namespace Dwm {
                 rc = true;
               }
               else {
-                Syslog(LOG_ERR, "Failed to verify message from %s",
-                       theirId.c_str());
+                Syslog(LOG_ERR,
+                       "Failed to verify message from %s at %s on fd %d",
+                       theirId.c_str(), peerName.c_str(), fd);
               }
             }
             else {
@@ -445,13 +503,13 @@ namespace Dwm {
             }
           }
           else {
-            Syslog(LOG_ERR, "ID and signature exhange with %s failed",
-                   inet_ntoa(sockAddr.sin_addr));
+            Syslog(LOG_ERR, "ID and signature exhange with %s on fd %d failed",
+                   peerName.c_str(), fd);
           }
         }
         else {
-          Syslog(LOG_ERR, "ECDH exhange with %s failed",
-                 inet_ntoa(sockAddr.sin_addr));
+          Syslog(LOG_ERR, "ECDH exhange with %s on fd %d failed",
+                 peerName.c_str(), fd);
         }
         setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, (char *)&origTcpNoDelay,
                    sizeof(origTcpNoDelay));
