@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.9/src/DwmAuthUtils.cc 11162 $
-// @(#) $Id: DwmAuthUtils.cc 11162 2020-09-08 06:46:41Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.12/src/DwmAuthUtils.cc 11368 $
+// @(#) $Id: DwmAuthUtils.cc 11368 2020-12-09 06:31:44Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2020
 //  All rights reserved.
@@ -53,7 +53,7 @@ extern "C" {
 #include "DwmSysLogger.hh"
 #include "DwmAuthUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.9/src/DwmAuthUtils.cc 11162 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.12/src/DwmAuthUtils.cc 11368 $");
 
 namespace Dwm {
 
@@ -102,6 +102,10 @@ namespace Dwm {
           }
         }
         rc = (bytesReady >= numBytes);
+        if (! rc) {
+          Syslog(LOG_DEBUG, "Timed out waiting for %lu bytes on fd %d",
+                 numBytes, fd);
+        }
       }
       return rc;
     }
