@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: TestAESGCMStreams.cc 10898 2020-08-12 19:46:32Z dwm $
+// @(#) $Id: TestAESGCMStreams.cc 11162 2020-09-08 06:46:41Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2020
 //  All rights reserved.
@@ -45,7 +45,7 @@
 
 #include <boost/asio.hpp>
 
-#include "DwmIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmUnitAssert.hh"
 #include "DwmAESGCMIstream.hh"
 #include "DwmAESGCMOstream.hh"
@@ -86,7 +86,7 @@ void ServerThread(const std::string & key, const std::string & plaintext)
     ip::tcp::iostream  stream(std::move(socket));
     Dwm::AESGCM::Ostream  os(stream, key);
     for (int i = 0; i < 10; ++i) {
-      if (! UnitAssert(Dwm::IO::Write(os, plaintext))) {
+      if (! UnitAssert(Dwm::StreamIO::Write(os, plaintext))) {
         break;
       }
       UnitAssert(os.flush());
@@ -174,7 +174,7 @@ void TestReadWrite4M()
       stringstream  ss;
       AESGCM::Ostream  xos(ss, key);
       auto  startTime = chrono::system_clock::now();
-      UnitAssert(Dwm::IO::Write(xos, plainstr));
+      UnitAssert(Dwm::StreamIO::Write(xos, plainstr));
       UnitAssert(xos.flush());
       auto  endTime = chrono::system_clock::now();
       auto  elapsedms =
@@ -187,7 +187,7 @@ void TestReadWrite4M()
       AESGCM::Istream  xis(ss, key);
       string  recoveredstr;
       startTime = chrono::system_clock::now();
-      if (UnitAssert(Dwm::IO::Read(xis, recoveredstr))) {
+      if (UnitAssert(Dwm::StreamIO::Read(xis, recoveredstr))) {
         endTime = chrono::system_clock::now();
         elapsedms =
           chrono::duration_cast<chrono::milliseconds>(endTime - startTime);
@@ -238,7 +238,7 @@ int main()
         Dwm::AESGCM::Istream  xis(tcpStream, key);
         std::string  recoveredString;
         for (int i = 0; i < 10; ++i) {
-          if (UnitAssert(Dwm::IO::Read(xis, recoveredString))) {
+          if (UnitAssert(Dwm::StreamIO::Read(xis, recoveredString))) {
             UnitAssert(recoveredString == fileContents);
           }
         }
